aboutsummaryrefslogtreecommitdiffstats
path: root/include/avirt/avirt.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/avirt/avirt.h')
-rw-r--r--include/avirt/avirt.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/avirt/avirt.h b/include/avirt/avirt.h
index 1ebed32..46c2c19 100644
--- a/include/avirt/avirt.h
+++ b/include/avirt/avirt.h
@@ -104,7 +104,7 @@ int snd_avirt_streams(struct snd_avirt_stream **streams, int *count);
int snd_avirt_audiopaths(struct snd_avirt_audiopath **audiopaths, int *count);
/**
* snd_avirt_card_seal - Finalize AVIRT stream creation and register sound card
* @return: 0 on success, negative ERRNO otherwise
*
* This should be called once all streams have been created via
@@ -114,7 +114,7 @@ int snd_avirt_audiopaths(struct snd_avirt_audiopath **audiopaths, int *count);
*
* NOTE: Once this function is called, no more streams may be added.
*/
-int snd_avirt_card_seal();
+int snd_avirt_card_configure();
/**
* snd_avirt_pcm_info - Get PCM info for a given PCM name
@@ -104,7 +104,7 @@ int snd_avirt_streams(struct snd_avirt_stream **streams, int *count);
int snd_avirt_audiopaths(struct snd_avirt_audiopath **audiopaths, int *count);
/**
- * snd_avirt_card_seal - Finalize AVIRT stream creation and register sound card
+ * snd_avirt_card_configure - Finalize AVIRT stream creation and register sound card
* @return: 0 on success, negative ERRNO otherwise
*